@@ -13,9 +13,7 @@ var text = 'digraph G {\n';
 text += 'ratio = 0.6;\n';
 text += 'rankdir=LR;\n';
 
-
 packages.forEach(function(packagePath) {
-
   // Load the package.json data.
   var dataPath = path.join(packagePath, 'package.json');
   try {
@@ -36,15 +34,15 @@ packages.forEach(function(packagePath) {
 
   // In order to cut down on the number of graph nodes,
   // don't include "*-extension" packages.
-  if (data.name.indexOf('-extension') !== -1 ) {
+  if (data.name.indexOf('-extension') !== -1) {
     return;
   }
 
   // Construct a URL to the package on GitHub.
-  var Url = url.resolve(baseUrl, 'packages/'+path.basename(packagePath));
+  var Url = url.resolve(baseUrl, 'packages/' + path.basename(packagePath));
 
   // Remove the '@jupyterlab' part of the name.
-  var name = '"'+data.name.split('/')[1] +'"';
+  var name = '"' + data.name.split('/')[1] + '"';
   text += name + '[URL="' + Url + '"];\n';
 
   var deps = data.dependencies || [];
@@ -53,12 +51,14 @@ packages.forEach(function(packagePath) {
     if (dep.indexOf('@jupyterlab') === -1) {
       continue;
     }
-    dep = '"'+dep.split('/')[1]+'"';
+    dep = '"' + dep.split('/')[1] + '"';
     text += name + ' -> ' + dep + ';\n';
   }
 });
 
 text += '}\n';
 fs.writeFileSync('./dependencies.gv', text);
-childProcess.execSync('cat dependencies.gv | tred | dot -Tsvg -o dependency-graph.svg');
+childProcess.execSync(
+  'cat dependencies.gv | tred | dot -Tsvg -o dependency-graph.svg'
+);
 fs.unlink('./dependencies.gv');
